"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LaneComponentDiff = void 0;
const component_id_1 = require("@teambit/component-id");
const change_type_1 = require("./change-type");
class LaneComponentDiff {
    constructor(componentId, changes, upToDate, sourceHead, targetHead) {
        this.componentId = componentId;
        this.changes = changes;
        this.upToDate = upToDate;
        this.sourceHead = sourceHead;
        this.targetHead = targetHead;
    }
    get new() {
        return this.changes.includes(change_type_1.ChangeType.NEW);
    }
    get changed() {
        return this.changes.length > 0 && !this.changes.includes(change_type_1.ChangeType.NEW) && !this.changes.includes(change_type_1.ChangeType.NONE);
    }
    get dependencyChanged() {
        return this.changes.includes(change_type_1.ChangeType.DEPENDENCY);
    }
    get sourceCodeChanged() {
        return this.changes.includes(change_type_1.ChangeType.SOURCE_CODE);
    }
    get changeType() {
        if (this.changes.length === 1)
            return this.changes[0];
        if (this.sourceCodeChanged)
            return change_type_1.ChangeType.SOURCE_CODE;
        if (this.dependencyChanged)
            return change_type_1.ChangeType.DEPENDENCY;
        if (this.new)
            return change_type_1.ChangeType.NEW;
        if (this.changes.includes(change_type_1.ChangeType.NONE))
            return change_type_1.ChangeType.NONE;
        return change_type_1.ChangeType.ASPECTS;
    }
    toObject() {
        return {
            componentId: this.componentId.toString(),
            changes: this.changes,
            upToDate: this.upToDate,
            sourceHead: this.sourceHead,
            targetHead: this.targetHead,
        };
    }
    static from(plainComponentDiff) {
        const id = component_id_1.ComponentID.fromString(plainComponentDiff.componentId);
        return new LaneComponentDiff(id, plainComponentDiff.changes, plainComponentDiff.upToDate, plainComponentDiff.sourceHead, plainComponentDiff.targetHead);
    }
}
exports.LaneComponentDiff = LaneComponentDiff;
//# sourceMappingURL=lane-component-diff.js.map